@@ -7,8 +7,8 @@ library(BioInstaller)
 blast.databases <- system.file('extdata', 
   'nongithub_databases_blast.toml', package = 'BioInstaller')
 
-read.config(blast.databases)$blast_nr$source_url
-read.config(blast.databases, glue.parse = TRUE)$blast_nr$source_url
+read.config(blast.databases)$blast_db_nr$source_url
+read.config(blast.databases, glue.parse = TRUE)$blast_db_nr$source_url
 mask.github <- tempfile()
 file.create(mask.github)
 install.bioinfo(nongithub.cfg = blast.databases, github.cfg = mask.github,
